// ============================================================================
// resgauge.c -- a gauge of free system resources.
//
// Richard Franklin Albury
// CIS: 76477,534
// ============================================================================


#include <windows.h>
#include "resgauge.h"


// ------------------
// symbolic constants
// ------------------
#define TIMER_ID  1
#define TIMER_MS  500
#define WM_REVERT WM_USER

// --------------------
// enumerated constants
// --------------------
enum
{
    ALARM_BEEP,
    ALARM_FLASH
};
enum
{
    MONITOR_USER,
    MONITOR_GDI,
    MONITOR_BOTH
};

// -------------------
// function prototypes
// -------------------
BOOL  NEAR PASCAL InitApplication(HANDLE hPrevInstance);
BOOL  NEAR PASCAL InitInstance(void);
LONG  FAR  PASCAL MainWndProc(HWND hWnd,
                              WORD wMessage,
                              WORD wParam,
                              LONG lParam);
BOOL  FAR  PASCAL AboutDlgProc(HWND hDlg,
                               WORD wMessage,
                               WORD wParam,
                               LONG lParam);
BOOL  FAR  PASCAL ConfigDlgProc(HWND hDlg,
                                WORD wMessage,
                                WORD wParam,
                                LONG lParam);
VOID  NEAR PASCAL EnableAlarmControls(HWND hDlg,
                                      BOOL fEnable);
WORD  NEAR PASCAL GetSystemResources(void);
void  NEAR PASCAL GetConfiguration(void);
void  NEAR PASCAL SaveConfiguration(void);
void  NEAR PASCAL CenterDialog(HWND hDlg);

// an undocumented Windows function ... one of many!
DWORD FAR  PASCAL GetHeapSpaces(HANDLE);

// --------------
// data structure
// --------------
typedef struct offset
{
    WORD wX;
    WORD wY;
} OFFSET;

// -------
// globals
// -------
char   GszAlarmEnabled[] = "AlarmEnabled";
char   GszAlarmType[]    = "AlarmType";
char   GszBeep[]         = "Beep";
char   GszBoth[]         = "Both";
char   GszClassName[]    = "ResGauge";
char   GszFlash[]        = "Flash";
char   GszFloat[]        = "Float";
char   GszGDI[]          = "GDI";
char   GszMonitor[]      = "Monitor";
char   GszProfileName[]  = ".\\resgauge.ini";
char   GszThreshhold[]   = "Threshhold";
char   GszUser[]         = "User";
BOOL   GfAlarmEnabled    = FALSE;
BOOL   GfFloat           = FALSE;
HANDLE GhInst;
OFFSET GaOffset[] =
       {
           {  0,  91},
           {  0,  94},
           {  0,  97},
           {  0, 100},
           {  1,  84},
           {  1,  87},
           {  2,  78},
           {  2,  81},
           {  3,  75},
           {  4,  72},
           {  5,  69},
           {  6,  66},
           {  7,  63},
           {  8,  60},
           { 10,  57},
           { 11,  55},
           { 12,  52},
           { 14,  49},
           { 16,  46},
           { 17,  44},
           { 19,  41},
           { 21,  39},
           { 23,  36},
           { 25,  34},
           { 27,  32},
           { 29,  29},
           { 32,  27},
           { 34,  25},
           { 36,  23},
           { 39,  21},
           { 41,  19},
           { 44,  17},
           { 46,  16},
           { 49,  14},
           { 52,  12},
           { 55,  11},
           { 57,  10},
           { 60,   8},
           { 63,   7},
           { 66,   6},
           { 69,   5},
           { 72,   4},
           { 75,   3},
           { 78,   2},
           { 81,   2},
           { 84,   1},
           { 87,   1},
           { 91,   0},
           { 94,   0},
           { 97,   0},
           {100,   0},
           {103,   0},
           {106,   0},
           {109,   0},
           {113,   1},
           {116,   1},
           {119,   2},
           {122,   2},
           {125,   3},
           {128,   4},
           {131,   5},
           {134,   6},
           {137,   7},
           {140,   8},
           {143,  10},
           {145,  11},
           {148,  12},
           {151,  14},
           {154,  16},
           {156,  17},
           {159,  19},
           {161,  21},
           {164,  23},
           {166,  25},
           {168,  27},
           {171,  29},
           {173,  32},
           {175,  34},
           {177,  36},
           {179,  39},
           {181,  41},
           {183,  44},
           {184,  46},
           {186,  49},
           {188,  52},
           {189,  55},
           {190,  57},
           {192,  60},
           {193,  63},
           {194,  66},
           {195,  69},
           {196,  72},
           {197,  75},
           {198,  78},
           {198,  81},
           {199,  84},
           {199,  87},
           {200,  91},
           {200,  94},
           {200,  97},
           {200, 100}
       };   
WORD   GwAlarmType       = ALARM_BEEP;
WORD   GwMonitor         = MONITOR_BOTH;
WORD   GwThreshhold      = 25;


// ============================================================================
// > > > > > > > > > > > > > > >  code  begins  < < < < < < < < < < < < < < < <
// ============================================================================
// The "main()" for Windows: calls the initialization functions and enters the
// message processing loop.  Returns the wParam element of the MSG when a
// WM_QUIT message has been processed by the window function.
// ----------------------------------------------------------------------------
short
PASCAL
WinMain(
HANDLE    hInstance,     // current instance
HANDLE    hPrevInstance, // previous instance
LPSTR     lpszCmdLine,   // command line
short     nCmdShow)      // window state (usually open or iconic)
{
    short nReturn;
    MSG   msg;

    nReturn = 0;
    GhInst = hInstance;
    if ( InitApplication(hPrevInstance) && InitInstance() )
    {
        while ( GetMessage(&msg, NULL, 0, 0) )
        {
            TranslateMessage(&msg);
            DispatchMessage(&msg);
        }
        nReturn = msg.wParam;
    }
    return(nReturn);
} // WinMain


// ----------------------------------------------------------------------------
// Initializes window data and registers the window class.
// ----------------------------------------------------------------------------
BOOL
PASCAL
NEAR
InitApplication(
HANDLE       hPrevInstance) // previous instance
{
    BOOL     fReturn;
    WNDCLASS wndclass;

    if ( hPrevInstance )
    {
        // we'd normally return TRUE, but in this case we only want the first
        // instance to run, so we return FALSE for all other instances
        fReturn = FALSE;
    }
    else
    {
        // register the main window class
        wndclass.style         = CS_HREDRAW | CS_VREDRAW;
        wndclass.lpfnWndProc   = MainWndProc;
        wndclass.cbClsExtra    = 0;
        wndclass.cbWndExtra    = 0;
        wndclass.hInstance     = GhInst;
        wndclass.hIcon         = NULL;
        wndclass.hCursor       = LoadCursor(NULL, IDC_ARROW);
        wndclass.hbrBackground = COLOR_WINDOW + 1;
        wndclass.lpszMenuName  = GszClassName;
        wndclass.lpszClassName = GszClassName;
        fReturn = RegisterClass(&wndclass);
    }

    return(fReturn);
} // InitApplication


// ----------------------------------------------------------------------------
// Creates the main window.
// ----------------------------------------------------------------------------
BOOL
PASCAL
NEAR
InitInstance(void)
{
    BOOL fReturn;
    HWND hWnd;

    // assume failure
    fReturn = FALSE;

    // get the configuration info
    GetConfiguration();

    // create the main window
    hWnd = CreateWindow(GszClassName,
                        GszClassName,
                        WS_OVERLAPPEDWINDOW,
                        CW_USEDEFAULT,
                        CW_USEDEFAULT,
                        CW_USEDEFAULT,
                        CW_USEDEFAULT,
                        0,
                        0,
                        GhInst,
                        NULL);
    if ( hWnd )
    {
        if ( SetTimer(hWnd, TIMER_ID, TIMER_MS, NULL) )
        {
            // normally, we'd call ShowWindow() with nCmdShow, but in this
            // case, we want the app to start up iconic, so we use
            // SW_SHOWMINNOACTIVE
            ShowWindow(hWnd, SW_SHOWMINNOACTIVE);
            UpdateWindow(hWnd);
            fReturn = TRUE;
        }
        else
        {
            MessageBox(hWnd,
                       "Too many timers in use!",
                       GszClassName,
                       MB_ICONEXCLAMATION | MB_OK);
        }
    }

    return(fReturn);
} // InitInstance


// ----------------------------------------------------------------------------
// Processes messages for the main window.
// ----------------------------------------------------------------------------
LONG
FAR
PASCAL
MainWndProc(
HWND            hWnd,     // window handle
WORD            wMessage, // type of message
WORD            wParam,   // 16 bits of information
LONG            lParam)   // 32 additional bits of information
{
    static WORD wFree;

    char        szBuffer[4];
    short       xText;
    short       yText;
    DWORD       dwExtent;
    HBRUSH      hBrush;
    HBRUSH      hOldBrush;
    HDC         hDC;
    HMENU       hMenu;
    LONG        lReturn;
    PAINTSTRUCT ps;
    RECT        rect;
    RECT        rectTmp;
    WORD        wTmp;
    WORD        wX;
    WORD        wY;

    lReturn = 0L;
    switch ( wMessage )
    {
        case WM_CREATE:
            hMenu = GetSystemMenu(hWnd, FALSE);
            AppendMenu(hMenu, MF_SEPARATOR, 0,             NULL);
            AppendMenu(hMenu, MF_STRING,    IDM_CONFIGURE, "C&onfigure...");
            AppendMenu(hMenu, MF_STRING,    IDM_ABOUT,     "A&bout...");
            DeleteMenu(hMenu, SC_MINIMIZE,  MF_BYCOMMAND);
            DeleteMenu(hMenu, SC_MAXIMIZE,  MF_BYCOMMAND);
            DeleteMenu(hMenu, SC_RESTORE,   MF_BYCOMMAND);
            DeleteMenu(hMenu, SC_SIZE,      MF_BYCOMMAND);
            DrawMenuBar(hWnd);
            wFree = GetSystemResources();
            break;

        case WM_TIMER:
            if ( GfFloat == TRUE )
            {
                SetWindowPos(hWnd,
                             NULL, 
                             0, 
                             0, 
                             0, 
                             0, 
                             SWP_NOSIZE | SWP_NOMOVE | SWP_NOACTIVATE); 
            }
            wTmp = GetSystemResources();
            if ( (GfAlarmEnabled) && (wTmp <= GwThreshhold) )
            {
                if ( GwAlarmType == ALARM_BEEP )
                    MessageBeep(0);
                else if ( GwAlarmType == ALARM_FLASH)
                    FlashWindow(hWnd, TRUE);
            }
            if ( wTmp != wFree )
            {
                wFree = wTmp;
                InvalidateRect(hWnd, NULL, TRUE);
            }
            break;

        case WM_SYSCOMMAND:
            switch ( wParam )
            {
                case IDM_ABOUT:
                    DialogBox(GhInst,
                              MAKEINTRESOURCE(IDDB_ABOUT),
                              hWnd,
                              AboutDlgProc);
                    break;
                case IDM_CONFIGURE:
                    DialogBox(GhInst,
                              MAKEINTRESOURCE(IDDB_CONFIGURE),
                              hWnd,
                              ConfigDlgProc);
                    break;
                default:
                    lReturn = DefWindowProc(hWnd, wMessage, wParam, lParam);
                    break;
            }
            break;

        case WM_PAINT:
            wsprintf(szBuffer, "%d%%", wFree);
            hDC = BeginPaint(hWnd, &ps);
            SelectObject(hDC, GetStockObject(ANSI_VAR_FONT));
            dwExtent = GetTextExtent(hDC, szBuffer, lstrlen(szBuffer));
            GetClientRect(hWnd, &rect);
            hBrush = CreateSolidBrush(RGB(0, 0, 0));
            hOldBrush = SelectObject(hDC, hBrush);
            FrameRect(hDC, &rect, hBrush);
            SelectObject(hDC, hOldBrush);
            DeleteObject(hBrush);
            rectTmp = rect;
            xText = rect.left +
                    ((rect.right - rect.left) - LOWORD(dwExtent)) / 2;
            yText = rect.top + rect.bottom - HIWORD(dwExtent) - 1;
            yText = rect.bottom - HIWORD(dwExtent) - 1;
            rectTmp.bottom = yText;
            InflateRect(&rectTmp, -2, -2);
            hBrush = CreateSolidBrush(RGB(255, 0, 0));
            hOldBrush = SelectObject(hDC, hBrush);
            wX = rectTmp.right - rectTmp.left;
            wY = rectTmp.bottom - rectTmp.top;
            Pie(hDC,
                rectTmp.left,
                rectTmp.top,
                rectTmp.right,
                rectTmp.bottom + (rectTmp.bottom - rectTmp.top) + 1,
                rectTmp.left + (GaOffset[wFree].wX * wX) / 200,
                rectTmp.top  + (GaOffset[wFree].wY * wY) / 100,
                rectTmp.left,
                rectTmp.bottom);
            SelectObject(hDC, hOldBrush);
            DeleteObject(hBrush);
            TextOut(hDC, xText, yText, szBuffer, lstrlen(szBuffer));
            EndPaint(hWnd, &ps);
            break;

        case WM_QUERYOPEN:
            break;

        case WM_DESTROY:
            KillTimer(hWnd, TIMER_ID);
            PostQuitMessage(0);
            break;

        default:
            lReturn = DefWindowProc(hWnd, wMessage, wParam, lParam);
            break;
    }

    return(lReturn);
} // MainWndProc


// ----------------------------------------------------------------------------
// Processes messages for the "About..." dialog box.
// ----------------------------------------------------------------------------
BOOL
FAR
PASCAL
AboutDlgProc(
HWND       hDlg,     // window handle of the dialog
WORD       wMessage, // type of message
WORD       wParam,   // 16 bits of information
LONG       lParam)   // 32 additional bits of information
{
    short  x;
    BOOL   fReturn;
    HANDLE hFont;

    fReturn = FALSE;
    switch ( wMessage )
    {
        case WM_INITDIALOG:
            // center the dialog
            CenterDialog(hDlg);

            // set the font of the text boxes
            hFont = GetStockObject(ANSI_VAR_FONT);
            SendDlgItemMessage(hDlg, IDOK, WM_SETFONT, hFont, FALSE);
            for ( x = IDD_ABOUT1; x <= LAST_ABOUT; ++x )
                SendDlgItemMessage(hDlg, x, WM_SETFONT, hFont, FALSE);
            fReturn = TRUE;
            break;

        case WM_COMMAND:
            if ( (wParam == IDOK) || (wParam == IDCANCEL) )
            {
                EndDialog(hDlg, TRUE);
                fReturn = TRUE;
            }
            break;
    }

    return(fReturn);
} // AboutDlgProc


// ----------------------------------------------------------------------------
// Processes messages for the "Configure..." dialog box.
// ----------------------------------------------------------------------------
BOOL
FAR
PASCAL
ConfigDlgProc(
HWND            hDlg,     // window handle of the dialog
WORD            wMessage, // type of message
WORD            wParam,   // 16 bits of information
LONG            lParam)   // 32 additional bits of information
{
    static BOOL fAlarmEnabled;
    static BOOL fFloat;
    static WORD wAlarmType;
    static WORD wMonitor;
    static WORD wThreshhold;

    short       x;
    BOOL        fEnable;
    BOOL        fNoError;
    BOOL        fReturn;
    HANDLE      hFont;
    WORD        wTmp;

    fReturn = FALSE;
    switch ( wMessage )
    {
        case WM_INITDIALOG:
            // center the dialog
            CenterDialog(hDlg);

            // set the font of the text boxes
            hFont = GetStockObject(ANSI_VAR_FONT);
            SendDlgItemMessage(hDlg, IDOK, WM_SETFONT, hFont, FALSE);
            SendDlgItemMessage(hDlg, IDCANCEL, WM_SETFONT, hFont, FALSE);
            for ( x = IDD_USER; x <= LAST_CONFIG; ++x )
                SendDlgItemMessage(hDlg, x, WM_SETFONT, hFont, FALSE);

            // save the global values
            fAlarmEnabled = GfAlarmEnabled;
            fFloat        = GfFloat;
            wAlarmType    = GwAlarmType;
            wMonitor      = GwMonitor;
            wThreshhold   = GwThreshhold;

            // update the controls
            switch ( GwMonitor )
            {
                case MONITOR_USER:
                    wTmp = IDD_USER;
                    break;

                case MONITOR_GDI:
                    wTmp = IDD_GDI;
                    break;

                case MONITOR_BOTH:
                    wTmp = IDD_BOTH;
                    break;

            }
			CheckRadioButton(hDlg, IDD_USER, IDD_BOTH, wTmp);

            switch ( GwAlarmType )
            {
                case ALARM_BEEP:
                    wTmp = IDD_BEEP;
                    break;

                case ALARM_FLASH:
                    wTmp = IDD_FLASH;
                    break;
            }
			CheckRadioButton(hDlg, IDD_BEEP, IDD_FLASH, wTmp);

	        SendDlgItemMessage(hDlg, IDD_FLOAT, BM_SETCHECK, GfFloat, 0L);
            SendDlgItemMessage(hDlg, IDD_PERCENT, EM_LIMITTEXT, 2, 0L);
            SetDlgItemInt(hDlg, IDD_PERCENT, GwThreshhold, FALSE);
            EnableAlarmControls(hDlg, GfAlarmEnabled);

            fReturn = TRUE;
            break;

        case WM_REVERT:
            SetDlgItemInt(hDlg, IDD_PERCENT, GwThreshhold, FALSE);
            break;

        case WM_COMMAND:
            switch ( wParam )
            {
                case IDD_USER:
			        CheckRadioButton(hDlg, IDD_USER, IDD_BOTH, wParam);
                    GwMonitor = MONITOR_USER;
                    break;

                case IDD_GDI:
			        CheckRadioButton(hDlg, IDD_USER, IDD_BOTH, wParam);
                    GwMonitor = MONITOR_GDI;
                    break;

                case IDD_BOTH:
			        CheckRadioButton(hDlg, IDD_USER, IDD_BOTH, wParam);
                    GwMonitor = MONITOR_BOTH;
                    break;

                case IDD_FLOAT:
			        fEnable = LOWORD(SendDlgItemMessage(hDlg,
                                                        wParam,
                                                        BM_GETCHECK,
                                                        0,
                                                        0L));
                    GfFloat = !fEnable;
	                SendDlgItemMessage(hDlg, wParam, BM_SETCHECK, GfFloat, 0L);
                    break;

                case IDD_ENABLE:
			        fEnable = LOWORD(SendDlgItemMessage(hDlg,
                                                        wParam,
                                                        BM_GETCHECK,
                                                        0,
                                                        0L));
                    GfAlarmEnabled = !fEnable;
                    EnableAlarmControls(hDlg, GfAlarmEnabled);
                    break;

                case IDD_BEEP:
			        CheckRadioButton(hDlg, IDD_BEEP, IDD_FLASH, wParam);
                    GwAlarmType = ALARM_BEEP;
                    break;

                case IDD_FLASH:
			        CheckRadioButton(hDlg, IDD_BEEP, IDD_FLASH, wParam);
                    GwAlarmType = ALARM_FLASH;
                    break;

                case IDD_MINUS:
                    GwThreshhold = GetDlgItemInt(hDlg,
                                                 IDD_PERCENT,
                                                 NULL,
                                                 FALSE);
                    if ( GwThreshhold > 1 )
                    {
                        --GwThreshhold;
                        SetDlgItemInt(hDlg, IDD_PERCENT, GwThreshhold, FALSE);
                    }
                    else
                    {
                        MessageBeep(0);
                    }
                    break;

                case IDD_PERCENT:
					if ( HIWORD(lParam) == EN_CHANGE )
                    {
                        wTmp = GetDlgItemInt(hDlg,
                                             IDD_PERCENT,
                                             (BOOL FAR *) &fNoError,
                                             FALSE);
                        if ( fNoError )
                        {
                            GwThreshhold = wTmp;
                        }
                        else
                        {
                            MessageBeep(0);
                            PostMessage(hDlg, WM_REVERT, 0, 0L);
                        }
                    }
                    break;

                case IDD_PLUS:
                    GwThreshhold = GetDlgItemInt(hDlg,
                                                 IDD_PERCENT,
                                                 NULL,
                                                 FALSE);
                    if ( GwThreshhold < 99 )
                    {
                        ++GwThreshhold;
                        SetDlgItemInt(hDlg, IDD_PERCENT, GwThreshhold, FALSE);
                    }
                    else
                    {
                        MessageBeep(0);
                    }
                    break;

                case IDD_APPLY:
                    EndDialog(hDlg, TRUE);
                    fReturn = TRUE;
                    break;

                case IDOK:
                    // save the settings only if they've changed
                    if ( (GfFloat        != fFloat)        ||
                         (GfAlarmEnabled != fAlarmEnabled) ||
                         (GwAlarmType    != wAlarmType)    ||
                         (GwMonitor      != wMonitor)      ||
                         (GwThreshhold   != wThreshhold) )
                    {
                        SaveConfiguration();
                    }
                    EndDialog(hDlg, TRUE);
                    fReturn = TRUE;
                    break;

                case IDCANCEL:
                    // restore the saved global values
                    GfAlarmEnabled = fAlarmEnabled;
                    GfFloat        = fFloat;
                    GwAlarmType    = wAlarmType;
                    GwMonitor      = wMonitor;
                    GwThreshhold   = wThreshhold;
                    EndDialog(hDlg, FALSE);
                    fReturn = TRUE;
                    break;
            }
            break;
    }

    return(fReturn);
} // ConfigDlgProc


// ----------------------------------------------------------------------------
// Enables/disables all the alarm controls.
// ----------------------------------------------------------------------------
VOID
NEAR
PASCAL
EnableAlarmControls(
HWND    hDlg,    // window handle of the dialog
BOOL    fEnable) // TRUE if the controls are to be enabled
{
    int x;

	SendDlgItemMessage(hDlg, IDD_ENABLE, BM_SETCHECK, fEnable, 0L);
    for ( x = IDD_BEEP; x <= IDD_THRESH; ++x )
        EnableWindow(GetDlgItem(hDlg, x), fEnable);
    for ( x = IDD_MINUS; x <= IDD_PLUS; ++x )
        EnableWindow(GetDlgItem(hDlg, x), fEnable);
} // EnableAlarmControls


// ----------------------------------------------------------------------------
// Uses an undocumented system call and the algorithm given in TIPS.TXT to
// calculate the percentage of free system resources.
// ----------------------------------------------------------------------------
WORD
NEAR
PASCAL
GetSystemResources(void)
{
    DWORD dwInfo;
    WORD  wFree;
    WORD  wGDI;
    WORD  wReturn;
    WORD  wSize;
    WORD  wUser;

    // get the information on the GDI module
    dwInfo = GetHeapSpaces(GetModuleHandle(GszGDI));
    wSize  = HIWORD(dwInfo);
    wFree  = LOWORD(dwInfo);
    wGDI   = (WORD) ((((DWORD) wFree) * 100L) / ((DWORD) wSize));

    // get the information on the User module
    dwInfo = GetHeapSpaces(GetModuleHandle(GszUser));
    wSize  = HIWORD(dwInfo);
    wFree  = LOWORD(dwInfo);
    wUser  = (WORD) ((((DWORD) wFree) * 100L) / ((DWORD) wSize));

    switch ( GwMonitor )
    {
        case MONITOR_USER:
            wReturn = wUser;
            break;

        case MONITOR_GDI:
            wReturn = wGDI;
            break;

        case MONITOR_BOTH:
            wReturn = min(wGDI, wUser);
            break;
    }

    return(wReturn);
} // GetSystemResources


// ----------------------------------------------------------------------------
// Retrieves the settings for the program.
// ----------------------------------------------------------------------------
void
NEAR
PASCAL
GetConfiguration(void)
{
	char szValue[32];

    // get the monitor type
	GetPrivateProfileString(GszClassName,
                            GszMonitor,
                            GszBoth,
                            szValue,
                            sizeof(szValue),
                            GszProfileName);
    if ( lstrcmpi(szValue, GszUser) == 0 )
        GwMonitor = MONITOR_USER;
    else if ( lstrcmpi(szValue, GszGDI) == 0 )
        GwMonitor = MONITOR_GDI;
    else
        GwMonitor = MONITOR_BOTH;

    // get the alarm setting
	GfAlarmEnabled = (GetPrivateProfileInt(GszClassName,
                                           GszAlarmEnabled,
                                           0,
                                           GszProfileName) ? TRUE : FALSE);

    // get the alarm type
	GetPrivateProfileString(GszClassName,
                            GszAlarmType,
                            GszBeep,
                            szValue,
                            sizeof(szValue),
                            GszProfileName);
    if ( lstrcmpi(szValue, GszFlash) == 0 )
        GwAlarmType = ALARM_FLASH;
    else
        GwAlarmType = ALARM_BEEP;

    // get the threshhold setting
	GwThreshhold = max(min(GetPrivateProfileInt(GszClassName,
                                                GszThreshhold,
                                                25,
                                                GszProfileName), 99), 1);

    // get the "float" setting
	GfFloat = (GetPrivateProfileInt(GszClassName,
                                    GszFloat,
                                    0,
                                    GszProfileName) ? TRUE : FALSE);
} // GetConfiguration


// ----------------------------------------------------------------------------
// Saves the settings for the program.
// ----------------------------------------------------------------------------
void
NEAR
PASCAL
SaveConfiguration(void)
{
    char  szThreshhold[4];
    LPSTR lpstr;

    // save the monitor type
    switch ( GwMonitor )
    {
        case MONITOR_USER:
            lpstr = GszUser;
            break;

        case MONITOR_GDI:
            lpstr = GszGDI;
            break;

        case MONITOR_BOTH:
            lpstr = GszBoth;
            break;
    }
    WritePrivateProfileString(GszClassName,
                              GszMonitor,
                              lpstr,
                              GszProfileName);

    // save the alarm setting
    WritePrivateProfileString(GszClassName,
                              GszAlarmEnabled,
                              GfAlarmEnabled ? "1" : "0",
                              GszProfileName);

    // save the alarm type
    switch ( GwAlarmType )
    {
        case ALARM_BEEP:
            lpstr = GszBeep;
            break;

        case ALARM_FLASH:
            lpstr = GszFlash;
            break;
    }
    WritePrivateProfileString(GszClassName,
                              GszAlarmType,
                              lpstr,
                              GszProfileName);

    // save the threshhold value
    wsprintf(szThreshhold, "%u", GwThreshhold);
    WritePrivateProfileString(GszClassName,
                              GszThreshhold,
                              szThreshhold,
                              GszProfileName);

    // save the "float" setting
    WritePrivateProfileString(GszClassName,
                              GszFloat,
                              GfFloat ? "1" : "0",
                              GszProfileName);
} // SaveConfiguration


// ----------------------------------------------------------------------------
// Centers the dialog.
// ----------------------------------------------------------------------------
void
NEAR
PASCAL
CenterDialog(
HWND      hDlg)
{
    short x;
    short y;
    short xSize;
    short ySize;
    RECT  rect;

    GetWindowRect(hDlg, &rect);
    xSize = rect.right - rect.left;
    ySize = rect.bottom - rect.top;
    x = GetSystemMetrics(SM_CXSCREEN);
    y = GetSystemMetrics(SM_CYSCREEN);
    MoveWindow(hDlg, (x - xSize) / 2, (y - ySize) / 2, xSize, ySize, TRUE);
} // CenterDialog


// =================
// end of resgauge.c
// =================
